@@ -14,10 +14,11 @@
 #include <QMessageBox>
 #include <QSplashScreen>
 #include <QTimer>
-#include "ImgArchiveSink.h"
-#include "Icons.h"
 #include "ComicMainWindow.h"
 #include "ComicBookSettings.h"
+#include "Thumbnail.h"
+#include "Page.h"
+#include "config.h"
 
 int main(int argc, char *argv[])
 {
@@ -26,52 +27,47 @@ int main(int argc, char *argv[])
 	QApplication app(argc, argv);
 	const QString errcaption = ComicMainWindow::tr("QComicBook error");
 
+        qRegisterMetaType<Page>("Page");
+        qRegisterMetaType<Thumbnail>("Thumbnail");
+
 	ComicBookSettings::instance().load();
 
-	//
-	// show splashscreen
-	QSplashScreen *splash = NULL;
-	if (ComicBookSettings::instance().showSplash())
-	{
-		QPixmap splashpix(DATADIR "qcomicbook-splash.png");
-		if (!splashpix.isNull())
-		{
-			splash = new QSplashScreen(splashpix);
-			splash->show();
-		}
-	}
 	
-	if (!Icons::init(DATADIR))
-		QMessageBox::critical(NULL, errcaption, ComicMainWindow::tr("Can't initialize icons path") + ":\n" DATADIR,
-				QMessageBox::Ok, QMessageBox::NoButton);
-
-	if (!ComicBookSettings::checkDirs())
+	if (!ComicBookSettings::instance().checkDirs())
+        {
 		QMessageBox::critical(NULL, errcaption, ComicMainWindow::tr("Can't initialize QComicBook directories"),
 				QMessageBox::Ok, QMessageBox::NoButton);
+        }
 	
-	//
-	// initialize unpackers
-	ImgArchiveSink::autoconfArchivers();
-		
 	ComicMainWindow *win = new ComicMainWindow(NULL);
 	//app.setMainWidget(win);
 	win->show();
 
 	//
-	// command line argument
-	if (app.argc() > 1)
-		win->open(QString::fromLocal8Bit(app.argv()[1]));
+	// show splashscreen
+	if (ComicBookSettings::instance().showSplash())
+	{
+		QPixmap splashpix(":/images/qcomicbook-splash.png");
+		if (!splashpix.isNull())
+		{
+                    QSplashScreen *splash = new QSplashScreen(splashpix, Qt::WindowStaysOnTopHint);
+                    splash->show();
+
+                    //
+                    // close splashscreen after a few seconds
+                    QTimer *timer = new QTimer(win);
+                    QObject::connect(timer, SIGNAL(timeout()), splash, SLOT(close()));
+                    timer->setSingleShot(true);
+                    timer->start(2*1000);
+		}
+	}
 
 	//
-	// close splashscreen after a few seconds
-	if (splash)
-	{
-		QTimer *timer = new QTimer(win);
-		QObject::connect(timer, SIGNAL(timeout()), splash, SLOT(close()));
-		timer->setSingleShot(true);
-		timer->start(2000);
-		//splash->finish(win);
-	}
+	// command line argument
+	if (app.argc() > 1)
+        { 
+            win->open(QString::fromLocal8Bit(app.argv()[1]));
+        }
 
 	return app.exec();
 }
